Module beamlit.models.function_release
======================================

Classes
-------

`FunctionRelease(from_: beamlit.types.Unset | str = <beamlit.types.Unset object>, to: beamlit.types.Unset | str = <beamlit.types.Unset object>)`
:   Function release, used to deploy a function from one environment to another
    
    Attributes:
        from_ (Union[Unset, str]): Origin environment from which the function is released
        to (Union[Unset, str]): Destination environment to which the function is released
    
    Method generated by attrs for class FunctionRelease.

    ### Static methods

    `from_dict(src_dict: dict[str, typing.Any]) ‑> ~T`
    :

    ### Instance variables

    `additional_keys: list[str]`
    :

    `additional_properties: dict[str, typing.Any]`
    :

    `from_: beamlit.types.Unset | str`
    :

    `to: beamlit.types.Unset | str`
    :

    ### Methods

    `to_dict(self) ‑> dict[str, typing.Any]`
    :